Crate unsafe_math_macro

Crate unsafe_math_macro 

unsafe_math proc macro

This crate contains the proc macro implementation for unsafe_math The macro replaces binary operations with calls to “fast” trait methods

Macros

unsafe_math_block
Version of unsafe_math macro that wraps statements. Replaces all binary operations with their unchecked/f_fast versions.

Attribute Macros

unsafe_math
Main unsafe_math macro. Replaces all binary operations with their unchecked/f_fast versions.